Changes
*******

0.2.1 (2015-04-13)
==================

* Updated Dockerfile template for CentOS builds (sudo was missing).

0.2.0 (2015-03-16)
==================

* Updated Dockerfile template for birdhouse environments.

0.1.1 (2014-11-13)
==================

* Updated Dockerfile template
starts only supervisord.
* Fixed example in Readme.

0.1.0 (2014-11-05)
==================

* Initial Release.
